/**
* @file bridgedcallconnecting_state.h
* @brief Declaration of BridgedCallConnectingState class
* @date Feb. 16, 2007
*
* DIALOGIC CONFIDENTIAL
* Copyright  2007 Dialogic Corporation. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to
* the source code (Material) are owned by Dialogic Corporation or its suppliers
* or licensors. Title to the Material remains with Dialogic Corporation or its
* suppliers and licensors. The Material contains trade secrets and proprietary
* and confidential information of Dialogic or its suppliers and licensors. The
* Material is protected by worldwide copyright and trade secret laws and treaty
* provisions. No part of the Material may be used, copied, reproduced,
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret or other intellectual
* property right is granted to or conferred upon you by disclosure or delivery
* of the Materials, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

#ifndef  _BRIDGEDCALLCONNECTING_STATE_H
#define  _BRIDGEDCALLCONNECTING_STATE_H

#include "bridgedcallstate.h"


//*****************************************************************************
// Class: ::BridgedCallConnectingState
// Description: This BridgedCallState subclass is for when a BridgedCall object
//              is waiting for the two endpoints to connect.
//*****************************************************************************
class BridgedCallConnectingState : public BridgedCallState
{
public:
   BridgedCallConnectingState(BridgedCall* pBridgedCall);
   virtual ~BridgedCallConnectingState();
   const char *GetStateStr() { return "CONNECTING     ";}
   E_BRIDGEDCALLSTATE GetState() { return CONNECTING_STATE;}
   void ProcessEvent(METAEVENT metaevent);

private:
   static const int H245_STARTED;
   static const int SIP_CONNECTED;
   static const int M3G_CONNECTED;
   static const int FULLY_CONNECTED;

   bool IsBridgedCallFullyConnected() { return(IsStatusSet(FULLY_CONNECTED));}
   void ProcessEndpointConnected(METAEVENT metaevent);
   void ProcessEndpointDisconnected(METAEVENT metaevent);
   void ProcessSipEndpointDisconnected(METAEVENT metaevent);
};

#endif


