/**
* @file mmepstate.h
* @brief Declaration of RTSPEPState class
* @date Feb. 20, 2007
*
* DIALOGIC CONFIDENTIAL
* Copyright  2007 Dialogic Corporation. All Rights Reserved.
* 
* The source code contained or described herein and all documents related to
* the source code (Material) are owned by Dialogic Corporation or its suppliers
* or licensors. Title to the Material remains with Dialogic Corporation or its
* suppliers and licensors. The Material contains trade secrets and proprietary
* and confidential information of Dialogic or its suppliers and licensors. The
* Material is protected by worldwide copyright and trade secret laws and treaty
* provisions. No part of the Material may be used, copied, reproduced,
* modified, published, uploaded, posted, transmitted, distributed, or disclosed
* in any way without Dialogic's prior express written permission.
* 
* No license under any patent, copyright, trade secret or other intellectual
* property right is granted to or conferred upon you by disclosure or delivery
* of the Materials, either expressly, by implication, inducement, estoppel or
* otherwise. Any license under such intellectual property rights must be
* express and approved by Dialogic in writing.
*/

#ifndef  _RTSPEPSTATE_H
#define  _RTSPEPSTATE_H

#include "gclib.h"

class RTSPEndpoint;

//*****************************************************************************
// Class: ::RTSPEPState
// Description: Abstract class for all RTSP endpoint states
//*****************************************************************************
class RTSPEPState
{
public:
   typedef enum
   {
      OPENING_STATE,
      PORTCONNECTING_STATE,
      IDLE_STATE,
      PLAYING_STATE,
      RECORDING_STATE,
      CLOSED_STATE,
      UNDEFINIED_STATE,
      NUM_RTSPEP_STATES
   }  E_RTSPEPSTATE;

   // Eliminate??
   typedef enum
   {
      USER_CONNECT_PROMPT,
      USER_DISCONNECT_PROMPT,
      USER_SEND_DIGIT_PROMPT,
      USER_SEND_FVU_PROMPT
   }  E_USER_PROMPT_TYPE;

   RTSPEPState(RTSPEndpoint* pRTSPEndpoint);
   virtual ~RTSPEPState();
   virtual void Reset() { m_StatusBitmask = 0;}
   virtual void ProcessEvent(METAEVENT metaevent) = 0;
   virtual void Shutdown() = 0;
   virtual const char* GetStateStr() = 0;
   virtual E_RTSPEPSTATE GetState() = 0;

protected:
   RTSPEndpoint *m_pRTSPEndpoint;
   int       m_StatusBitmask;
};

#endif

